@@ -27,7 +27,6 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "oxygensimulator.h"
-#include "oxygensimulator.moc"
 
 
 #include <QAbstractItemView>
@@ -65,10 +64,6 @@ namespace Oxygen
     bool Simulator::_grabMouse = true;
     int Simulator::_defaultDelay = 250;
 
-    //_______________________________________________________________________
-    Simulator::~Simulator( void )
-    {}
-
     //_______________________________________________________________________
     void Simulator::wait( int delay )
     { _events.append( Event( Event::Wait, 0, delay ) ); }
